# Bullet

Describes the bullet of a paragraph.

**Type:** object

## Properties

- **listId** (string): The ID of the list this paragraph belongs to.
- **nestingLevel** (integer): The nesting level of this paragraph in the list.
- **textStyle** ([TextStyle](textstyle.md)): The paragraph-specific text style applied to this bullet.
